@@ -206,7 +206,7 @@ void Backend::reloadCache()
     int count = 0;
     QSet<Group> groupSet;
 
-    d->isMultiArch = APT::Configuration::getArchitectures(false).size() > 1;
+    d->isMultiArch = architectures().size() > 1;
     bool pkgMultiArch;
     QString arch;
 
@@ -218,17 +218,6 @@ void Backend::reloadCache()
 
         Package *pkg = new Package(this, depCache, d->records, iter);
 
-        if (d->isMultiArch) {
-            // Do not add non-multiarch packages
-            pkgMultiArch = pkg->isMultiArchEnabled();
-            arch = pkg->architecture();
-
-            if (!pkgMultiArch && (arch != d->nativeArch) && (arch != QLatin1String("all"))) {
-                delete pkg;
-                continue;
-            }
-        }
-
         d->packagesIndex[iter->ID] = count;
         d->packages.append(pkg);
         ++count;
@@ -520,7 +509,7 @@ PackageList Backend::search(const QString &searchString) const
     }
 
     string unsplitSearchString = searchString.toStdString();
-    static int qualityCutoff = 25;
+    static int qualityCutoff = 15;
     PackageList searchResult;
 
     // Doesn't follow style guidelines to ease merging with synaptic
@@ -615,6 +604,28 @@ bool Backend::isMultiArchEnabled() const
     return d->isMultiArch;
 }
 
+QStringList Backend::architectures() const
+{
+    std::vector<std::string> archs = APT::Configuration::getArchitectures(false);
+
+    QStringList archList;
+    for (std::vector<std::string>::const_iterator a = archs.begin();
+         a != archs.end(); ++a)
+    {
+         archList.append(QString::fromStdString(*a));
+    }
+
+
+    return archList;
+}
+
+QString Backend::nativeArchitecture() const
+{
+    Q_D(const Backend);
+
+    return d->nativeArch;
+}
+
 bool Backend::areChangesMarked() const
 {
     return (toInstallCount() + toRemoveCount());
