@@ -130,8 +130,22 @@ public:
     */
     QString upstreamVersion() const;
 
+   /**
+    * Returns the upstream portion of @c version
+    *
+    * @param version The version to get the upstream portion from
+    *
+    * @return The upstream version from the given version string
+    */
     static QString upstreamVersion(const QString &version);
 
+   /**
+    * Returns the CPU architecture that the package supports
+    *
+    * @return The package's architecture
+    */
+    QString architecture() const;
+
    /**
     * Returns a list of all available versions of the package in the form of
     * "version, release" (E.g. "0.2-0ubuntu1, maverick")
@@ -364,6 +378,21 @@ public:
     */
     bool isSupported() const;
 
+   /**
+    * Returns whether or not a package is MultiArch-enabled.
+    *
+    * This function was made under the false assumption that non-native
+    * binary packages were considered MultiArch by APT. This is not true,
+    * so this function was renamed to isForeignArch() and expanded to include
+    * non-native binary packages.
+    */
+    QT_DEPRECATED bool isMultiArchEnabled() const;
+
+   /**
+    * Returns whether or not the package is for the native CPU architecture
+    */
+    bool isForeignArch() const;
+
     QList<DependencyItem> depends() const;
 
     QList<DependencyItem> preDepends() const;
